    /* sanity test */
#ifdef WANT_HCJ_RS232
#  ifdef WANT_WENK_RS232
#    error "define one of WANT_HCJ_RS232 or WANT_WENK_RS232 not both"
#  endif
#endif

#ifndef WANT_HCJ_RS232
#  ifndef WANT_WENK_RS232
#    ifndef KERNEL
/* we will assume WANT_HCJ_RS232 by default (but not while compiling KERNEL) */
#      define WANT_HCJ_RS232
#    endif
#  endif
#endif


/* Data structures for IOCTL. */

struct sgttyb {
  char sg_ispeed;		/* input speed ( used) */
  char sg_ospeed;		/* output speed (may or may not be used) */
  char sg_erase;		/* erase character */
  char sg_kill;			/* kill character */
#ifndef __GNUC__
  int  sg_flags;		/* mode flags */
#else
  short  sg_flags;		/* mode flags */
#endif
};

struct tchars {
  char t_intrc;			/* SIGINT char */
  char t_quitc;			/* SIGQUIT char */
  char t_startc;		/* start output (initially CTRL-Q) */
  char t_stopc;			/* stop output	(initially CTRL-S) */
  char t_eofc;			/* EOF (initially CTRL-D) */
  char t_brkc;			/* input delimiter (like nl) */
};

    /*  Common Defs */
/* every one thinks XTABS is 06000 but only 1 bit is needed: */
#define XTABS	     0004000	/* do tab expansion */
#define RAW	     0000040	/* enable raw mode */

#define CRMOD	     0000020	/* map lf to cr + lf */
/* the following is a magic cookie, the same name and value with termio.h */
#define ECHO	     0000010	/* echo input */
#define CBREAK	     0000002	/* enable cbreak mode */
#define COOKED       0000000	/* neither CBREAK nor RAW */

#define TIOCGETP (('t'<<8) | 8)
#define TIOCSETP (('t'<<8) | 9)
#define TIOCGETC (('t'<<8) | 18)
#define TIOCSETC (('t'<<8) | 17)

  /* defs unique to HCJ_RS232 */
#ifdef WANT_HCJ_RS232
/* Field names */
#define IN_CANON     0001000	/* when off, no special processing on input */
                                /* the VEOF is how many inchars to wakeup on*/
#define OCRMOD	     0000001	/* map lf to cr + lf OUTPUT */
/* when IN_CANON is OFF, then we will interpret additional bits for special
 * processing
 */
#define SPECIAL_0    0000040
#define SPECIAL_1    0000100

#define TIOCSTART (('t'<<8) | 1)
#define TIOCSTOP (('t'<<8) | 2)

/* Baud rates for rs232 */
#define B19200	0
#define B9600	1
#define B4800	2
#define B3600	3
#define B2400	4
#define B2000	5
#define B1800	6
#define B1200	7
#define B600	8
#define B300	9
#define B200	10
#define B150	11
#define B134	12
#define B110	13
#define B75	14
#define B50	15


/* these ioctls for rs232 taken from termio.h */
#ifndef TCGETA

#define	TC_RS232	('T'<<8)
#define	TCGETA		(TC_RS232|1)
#define	TCSETA		(TC_RS232|2)
#define	TCSETAW		(TC_RS232|3)	/* wait for output to drain */
#define	TCSETAF		(TC_RS232|4)    /* wait for output to dran, then flush input */
#define	TCSBRK		(TC_RS232|5)	/* drain output, send a break */
#define	TCXONC		(TC_RS232|6)	/* start/stop output arg ==0 stop, ==1 start */
#define	TCFLSH		(TC_RS232|7)	/* flush: 0==input 1==output 2=both */
#define	TCDSET		(TC_RS232|32)
#define	TCFLOW		(TC_RS232|33)
#define	TCFLOWON	(TC_RS232|34)
#define	TCFLOWOFF	(TC_RS232|35)
#define	FIONREAD	(TC_RS232|36)	/* return num chars in read Q */
#define	TCGETRS		(TC_RS232|37)
#define	TCSETDTR	(TC_RS232|38) /* |rts|dtr| each 2 bits: 01=off 10=on */
    				      /* arg ....xy; x=rts, y=dtr */
#define	TCSETBAUD	(TC_RS232|39)	/* set only baud rate - external */
#define	TCBAUD		(TC_RS232|99)	/* used by rstty.c internally */
#endif

#endif /* WANT_HCJ_RS232 */

    /* defs unique to WENK_RS232 */
#ifdef WANT_WENK_RS232
/* Field names */
#define BITS8        0001400	/* 8 bits/char */
#define BITS7        0001000	/* 7 bits/char */
#define BITS6        0000400	/* 6 bits/char */
#define BITS5        0000000	/* 5 bits/char */
#define EVENP        0000200	/* even parity */
#define ODDP         0000100	/* odd  parity */

/* Line speeds */
#define B0	0xff		/* sends BREAK */
#define B50	0x01
#define B75	0x02
#define B110	0x03
#define B134	0x04
#define B150	0x05
#define B200	0x06
#define B300	0x07
#define B600	0x08
#define B1200	0x09
#define B1800	0x0a
#define B2000	0x0b
#define B2400	0x0c
#define B3600	0x0d
#define B4800	0x0e
#define B9600	0x0f
#define B19200	0x10
#define EXTA	B19200
#define EXTB	0x00

#endif /* WANT_WENK_RS232 */

/* defs for disk controller based clocks */

#define	 DCLOCK	('D'<<8)

#define	DC_RBMS100	(DCLOCK|1)
#define	DC_RBMS200	(DCLOCK|2)
#define	DC_RSUPRA	(DCLOCK|3)
#define	DC_RICD  	(DCLOCK|4)
#define	DC_WBMS100	(DCLOCK|8)
#define	DC_WBMS200	(DCLOCK|9)
#define DC_WSUPRA	(DCLOCK|10)

/* defs for floppy/hard disk controller */
#define	_FDCHDC	('F'<<8)
#define DKGETP	(_FDCHDC|1)		/* get boot sector (struct block0) */
					/* see stboots.h for struct block0 */
/* the following are understood only by the hard disk driver */
#define DKPART	(_FDCHDC|2)		/* get partition info (struct part)  */
					/* see stboots.h for struct parts    */
 /* the following are for support of removable media hard drives */
#define DKOPEN	(_FDCHDC|3)		/* open a drive (after a DKCLOSE) */
#define DKCLOSE (_FDCHDC|4)		/* close a drive	          */


#ifdef __STDC__
/* **SHOULD BE** int	ioctl(int, int, void *); */
extern int ioctl();
#ifndef __NO_PROTO__
int	gtty(int, struct sgttyb *);
int	stty(int, struct sgttyb *);
#else
extern int	gtty();
extern int	stty();
#endif
#endif
